==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Image/Gui/Resources/translations/Image_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Grafik</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Erstellen Sie eine Bildebene...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Ein planare Grafik im 3D-Raum erzeugen</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>Erstellen Sie eine ebenes Bild im 3D-Raum</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Grafik</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Öffnen...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Öffne Bildansicht</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Undefinierter Farbraum-Typ für die Bildbetrachtung</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Pixelformat des Bildes</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Orientierung wählen</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Bildebene</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>XY-Ebene</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>XZ-Ebene</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>YZ-Ebene</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Umgekehrte Richtung</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Versatz:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>Bild an&amp;passen</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Bild auf die Ansicht ausdehnen</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp;1:1 Maßstab</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Das Bild im Maßstab 1:1 anzeigen</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp;Ursprüngliche Farbe</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Das Bild mit seinen ursprünglichen Farbe(n) anzeigen</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Farbe aufhellen</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Das Bild mit aufgehellten Farben anzeigen</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Fertig...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>grau</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>Zoom</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>außerhalb Bild</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Bildbetrachter</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Bilder (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+20"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Wählen Sie ein Bild zum Öffnen aus</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Bilder</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Alle Dateien</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Fehler beim Öffnen des Bildes</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Das gewählte Bild konnte nicht geladen werden</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Fehler beim Öffnen des Bildes</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Das gewählte Bild konnte nicht geladen werden</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Grafik</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Image/Gui/Resources/translations/Image_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Grafik</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Erstellen Sie eine Bildebene...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Ein planare Grafik im 3D-Raum erzeugen</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>Erstellen Sie eine ebenes Bild im 3D-Raum</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Grafik</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Öffnen...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Öffne Bildansicht</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location line="+120"/>
      <source>Image</source>
      <translation>Grafik</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Scale...</source>
      <translation>Skalieren...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Image Scaling</source>
      <translation>Bildskalierung</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Undefinierter Farbraum-Typ für die Bildbetrachtung</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Pixelformat des Bildes</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Orientierung wählen</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Bildebene</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>XY-Ebene</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>XZ-Ebene</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>YZ-Ebene</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Umgekehrte Richtung</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Versatz:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>Bild an&amp;passen</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Bild auf die Ansicht ausdehnen</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp;1:1 Maßstab</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Das Bild im Maßstab 1:1 anzeigen</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp;Ursprüngliche Farbe</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Das Bild mit seinen ursprünglichen Farbe(n) anzeigen</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Farbe aufhellen</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Das Bild mit aufgehellten Farben anzeigen</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Fertig...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>grau</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>Zoom</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>außerhalb Bild</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Bildbetrachter</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Bilder (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-102"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Wählen Sie ein Bild zum Öffnen aus</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Bilder</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Alle Dateien</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Fehler beim Öffnen des Bildes</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Das gewählte Bild konnte nicht geladen werden</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Fehler beim Öffnen des Bildes</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Das gewählte Bild konnte nicht geladen werden</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Grafik</translation>
    </message>
  </context>
</TS>
